@@ -1,6 +1,7 @@
 use std::{
     collections::HashMap,
     fs,
+    io::Read,
     path::PathBuf,
     time::{Duration, SystemTime},
 };
@@ -58,41 +59,55 @@ pub fn init_cache() -> anyhow::Result<PathBuf> {
 }
 
 pub fn get_templates() -> anyhow::Result<HashMap<String, String>> {
-    if let Some(cache_dir) = CACHE_DIR.to_owned() {
-        let dir = fs::read_dir(cache_dir).with_context(|| "Failed to read cache directory")?;
+    let cache_dir = CACHE_DIR.to_owned().context("Cache directory not found")?;
+    let dir = fs::read_dir(cache_dir).with_context(|| "Failed to read cache directory")?;
 
-        let ignores_tuple = dir
-            .filter(|e| {
-                if let Ok(entry) = e {
-                    entry.file_type().unwrap().is_file()
-                        && entry.file_name().to_str().unwrap().ends_with(".gitignore")
-                } else {
-                    false
-                }
-            })
-            .map(|e| -> anyhow::Result<(String, String)> {
-                let entry = e?;
-                let file_name = entry.file_name();
-                let name = file_name
-                    .to_str()
-                    .context("Failed to parse file name")?
-                    .split('.')
-                    .next()
-                    .context("Failed to parse file name")?
-                    .to_owned();
+    let ignores_tuple = dir
+        .filter(|e| {
+            if let Ok(entry) = e {
+                entry.file_type().unwrap().is_file()
+                    && entry.file_name().to_str().unwrap().ends_with(".gitignore")
+            } else {
+                false
+            }
+        })
+        .map(|e| -> anyhow::Result<(String, String)> {
+            let entry = e?;
+            let file_name = entry.file_name();
+            let name = file_name
+                .to_str()
+                .context("Failed to parse file name")?
+                .split('.')
+                .next()
+                .context("Failed to parse file name")?
+                .to_owned();
 
-                Ok((name.to_lowercase(), name))
-            })
-            .collect::<anyhow::Result<Vec<_>>>()?;
+            Ok((name.to_lowercase(), name))
+        })
+        .collect::<anyhow::Result<Vec<_>>>()?;
 
-        let mut ignores = HashMap::<String, String>::new();
+    let mut ignores = HashMap::<String, String>::new();
 
-        for (lower, path) in ignores_tuple {
-            ignores.insert(lower, path);
-        }
+    for (lower, path) in ignores_tuple {
+        ignores.insert(lower, path);
+    }
 
-        Ok(ignores)
+    Ok(ignores)
+}
+
+pub fn get_template(name: &str) -> anyhow::Result<String> {
+    let cache_dir = CACHE_DIR.to_owned().context("Cache directory not found")?;
+    let filename = name.to_owned() + ".gitignore";
+
+    let path = cache_dir.join(filename);
+
+    if !path.exists() {
+        return Err(anyhow::anyhow!("Template not found"));
     } else {
-        crate::remote::get_templates()
+        let mut file = fs::File::open(path).with_context(|| "Failed to open template file")?;
+        let mut str = String::new();
+        file.read_to_string(&mut str)?;
+
+        Ok(str)
     }
 }
