@@ -6,14 +6,7 @@ use std::{
 
 use anyhow::Context;
 
-use crate::{flush_stdout, lib::get_templates};
-
-pub fn get_contents_remote(template_path: &str) -> anyhow::Result<Vec<u8>> {
-    let url = crate::parse_url!(template_path);
-    let contents = crate::remote::get_url(&url)?.text()?.as_bytes().to_vec();
-
-    Ok(contents)
-}
+use crate::{cache::get_template, flush_stdout, lib::get_templates};
 
 pub fn pull_template() -> anyhow::Result<()> {
     let template = env::args()
@@ -56,14 +49,14 @@ pub fn pull_template() -> anyhow::Result<()> {
 
         if CACHE_ENABLED.to_owned() {
             println!("Getting template {}", template_path);
-            get_contents_remote(template_path)?
+            get_template(template_path)?
         } else {
-            Vec::new()
+            String::new()
         }
     };
 
     let mut file = File::create(path).with_context(|| "Failed to create file")?;
-    file.write_all(&contents)
+    file.write_all(contents.as_bytes())
         .with_context(|| "Failed to write to file")?;
 
     Ok(())
