@@ -7,13 +7,6 @@ macro_rules! flush_stdout {
     };
 }
 
-#[macro_export]
-macro_rules! create_client {
-    () => {
-        reqwest::blocking::Client::new()
-    };
-}
-
 #[macro_export]
 macro_rules! sleep_for {
     ($time:expr) => {
